==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/user/messages/pt/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => '<strong>Definições da Conta</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirmar</strong> o novo endereço email',
    '<strong>Permissions</strong>' => '<strong>Permissões</strong>',
    '<strong>Your</strong> Account' => 'A  Sua <strong>Conta</strong>',
    '<strong>Your</strong> profile' => 'O Seu <strong>Perfil</strong>',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Adicione tags ao seu perfil, descrevendo-se e realçando as suas habilitações e interesses. As suas tags serão exibidas no seu perfil e no diretório de utilizadores.',
    'All your personal data will be irrevocably deleted.' => 'Todos os seus dados pessoais serão irrevogavelmente eliminados.',
    'Are you sure that you want to delete your account?' => 'Tem a certeza que quer eliminar a sua conta?',
    'Blocked users' => 'Utilizadores bloqueados',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Trocar de nome de utilizador pode tornar alguns links inutilizáveis, por exemplo links antigos para o perfil.',
    'Confirm' => 'Confirmar',
    'Current password' => 'Palavra-passe atual',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Defina as funções básicas para o seu perfil. Pode adicionar tags que se relacionem consigo, escolher a língua, o fuso horário e bloquear utilizadores.',
    'Delete account' => 'Eliminar conta',
    'Do you really want to delete your icon image?' => 'Quer mesmo eliminar o seu ícone?',
    'Do you really want to delete your logo image?' => 'Quer mesmo eliminar o seu logo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Alterar e-mail',
    'Enter your password to continue' => 'Escreva a sua palavra-passe para continuar',
    'General' => 'Geral',
    'Hello' => 'Olá',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aqui pode editar os dados gerais que são visíveis na página \'Sobre\' do seu perfil',
    'Hide introduction tour panel on dashboard' => 'Esconder a janela de visita introdutória no painel',
    'Hide my online status' => 'Esconder o meu estado online',
    'Invalid link! Please make sure that you entered the entire url.' => 'Link inválido! Por favor, confirme se digitou a url inteira.',
    'Language' => 'Língua',
    'Markdown Editor Mode' => 'Modo de Editor Markdown',
    'Modules' => 'Módulos',
    'New E-Mail address' => 'Novo endereço de  e-mail',
    'New User name' => 'Novo nome de utilizador',
    'Not registered users' => 'Utilizadores não registados',
    'Notifications' => 'Notificações',
    'Other users' => 'Outros utilizadores',
    'Password Recovery' => 'Recuperar palavra-passe',
    'Permissions' => 'Permissões',
    'Plain' => 'Sem Formatação',
    'Profile' => 'Perfil',
    'Profile Tags' => 'Tags do Perfil',
    'Profile visibility' => 'Visibilidade do perfil',
    'Registered users only' => 'Unicamente para utilizadores registados',
    'Rich Text' => 'Texto Formatado',
    'Save' => 'Guardar',
    'Save profile' => 'Guardar perfil',
    'The entered e-mail address is already in use by another user.' => 'O e-mail introduzido já está em uso por outro utilizador.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Estas definições permitem que determine permissões a conceder a visitantes do seu perfil individual. Cada utilizador pode livremente ajustar as definições do seu próprio perfil.',
    'TimeZone' => 'Fuso horário',
    'Username has been changed' => 'O nome de utilizador foi alterado',
    'Users' => 'Utilizadores',
    'Visible for all (also unregistered users)' => 'Visível para todos os utilizadores (incluindo os não registados)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabámos de enviar um email de confirmação para o seu novo endereço.<br> Por favor, siga as instruções lá incluídas.',
    'You are currently the owner of following spaces:' => 'É atualmente responsável pelos seguintes espaços:',
    'You cannot use this username.' => 'Não pode utilizar este nome de utilizador.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Pediu para alterar o seu endereço email.<br>O seu novo endereço email é {newemail}.<br>Para confirmar o seu novo endereço email, por favor clique no botão abaixo.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Sucesso na mudança de nome de utilizador.<br>O seu novo nome de utilizador é {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Tem de transferir a responsabilidade ou eliminar estes espaços antes de eliminar a sua conta.',
    'Your account cannot be deleted!' => 'A sua conta não pode ser eliminada!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'O seu atual endereço de e-mail é <b>{email}<b>. Pode alterar o seu e mail atual aqui.</b></b>',
    'Your current password can be changed here.' => 'A sua palavra-passe atual pode ser alterada aqui.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'O seu nome de utilizador atual é <b>{username}</b>. Pode alterar o seu nome de utilizador aqui.',
    'Your e-mail address has been successfully changed to {email}.' => 'O seu endereço e-mail foi alterado com êxito para <b>{email}<b>.</b></b>',
    'Your friends' => 'Os seus amigos',
    'Your password has been successfully changed!' => 'A sua palavra-passe foi alterada com êxito!',
    'Your username has been changed' => 'O seu nome de utilizador foi alterado',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'O seu nome de utilizador foi alterado com êxito. <br> Acabámos de enviar-lhe um email com a nova informação.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/pt/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => '<strong>Definições da Conta</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Confirmar</strong> o novo endereço email',
    '<strong>Permissions</strong>' => '<strong>Permissões</strong>',
    '<strong>Your</strong> Account' => 'A  Sua <strong>Conta</strong>',
    '<strong>Your</strong> profile' => 'O Seu <strong>Perfil</strong>',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Adicione tags ao seu perfil, descrevendo-se e realçando as suas habilitações e interesses. As suas tags serão exibidas no seu perfil e no diretório de utilizadores.',
    'All your personal data will be irrevocably deleted.' => 'Todos os seus dados pessoais serão irrevogavelmente eliminados.',
    'Are you sure that you want to delete your account?' => 'Tem a certeza que quer eliminar a sua conta?',
    'Blocked users' => 'Utilizadores bloqueados',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Trocar de nome de utilizador pode tornar alguns links inutilizáveis, por exemplo links antigos para o perfil.',
    'Confirm' => 'Confirmar',
    'Current password' => 'Palavra-passe atual',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Defina as funções básicas para o seu perfil. Pode adicionar tags que se relacionem consigo, escolher a língua, o fuso horário e bloquear utilizadores.',
    'Delete account' => 'Eliminar conta',
    'Do you really want to delete your icon image?' => 'Quer mesmo eliminar o seu ícone?',
    'Do you really want to delete your logo image?' => 'Quer mesmo eliminar o seu logo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Alterar e-mail',
    'Enter your password to continue' => 'Escreva a sua palavra-passe para continuar',
    'General' => 'Geral',
    'Hello' => 'Olá',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Aqui pode editar os dados gerais que são visíveis na página \'Sobre\' do seu perfil',
    'Hide introduction tour panel on dashboard' => 'Esconder a janela de visita introdutória no painel',
    'Hide my online status' => 'Esconder o meu estado online',
    'Invalid link! Please make sure that you entered the entire url.' => 'Link inválido! Por favor, confirme se digitou a url inteira.',
    'Language' => 'Língua',
    'Markdown Editor Mode' => 'Modo de Editor Markdown',
    'Modules' => 'Módulos',
    'New E-Mail address' => 'Novo endereço de  e-mail',
    'New User name' => 'Novo nome de utilizador',
    'Not registered users' => 'Utilizadores não registados',
    'Notifications' => 'Notificações',
    'Other users' => 'Outros utilizadores',
    'Password Recovery' => 'Recuperar palavra-passe',
    'Permissions' => 'Permissões',
    'Plain' => 'Sem Formatação',
    'Profile' => 'Perfil',
    'Profile Tags' => 'Tags do Perfil',
    'Profile visibility' => 'Visibilidade do perfil',
    'Registered users only' => 'Unicamente para utilizadores registados',
    'Rich Text' => 'Texto Formatado',
    'Save' => 'Guardar',
    'Save profile' => 'Guardar perfil',
    'The entered e-mail address is already in use by another user.' => 'O e-mail introduzido já está em uso por outro utilizador.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Estas definições permitem que determine permissões a conceder a visitantes do seu perfil individual. Cada utilizador pode livremente ajustar as definições do seu próprio perfil.',
    'TimeZone' => 'Fuso horário',
    'Username has been changed' => 'O nome de utilizador foi alterado',
    'Users' => 'Utilizadores',
    'Visible for all (also unregistered users)' => 'Visível para todos os utilizadores (incluindo os não registados)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Acabámos de enviar um email de confirmação para o seu novo endereço.<br> Por favor, siga as instruções lá incluídas.',
    'You are currently the owner of following spaces:' => 'É atualmente responsável pelos seguintes espaços:',
    'You cannot use this username.' => 'Não pode utilizar este nome de utilizador.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Pediu para alterar o seu endereço email.<br>O seu novo endereço email é {newemail}.<br>Para confirmar o seu novo endereço email, por favor clique no botão abaixo.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Sucesso na mudança de nome de utilizador.<br>O seu novo nome de utilizador é {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Tem de transferir a responsabilidade ou eliminar estes espaços antes de eliminar a sua conta.',
    'Your account cannot be deleted!' => 'A sua conta não pode ser eliminada!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'O seu atual endereço de e-mail é <b>{email}<b>. Pode alterar o seu e mail atual aqui.</b></b>',
    'Your current password can be changed here.' => 'A sua palavra-passe atual pode ser alterada aqui.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'O seu nome de utilizador atual é <b>{username}</b>. Pode alterar o seu nome de utilizador aqui.',
    'Your e-mail address has been successfully changed to {email}.' => 'O seu endereço e-mail foi alterado com êxito para <b>{email}<b>.</b></b>',
    'Your friends' => 'Os seus amigos',
    'Your password has been successfully changed!' => 'A sua palavra-passe foi alterada com êxito!',
    'Your username has been changed' => 'O seu nome de utilizador foi alterado',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'O seu nome de utilizador foi alterado com êxito. <br> Acabámos de enviar-lhe um email com a nova informação.',
    'Do you really want to delete your login background image?' => '',
    'Do you really want to delete your mail header image?' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];
